@@ -38,7 +38,6 @@
 #include <glib/gi18n.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "gedit2.h"
@@ -53,9 +52,6 @@
 #include "gedit-application-server.h"
 #include "gedit-convert.h"
 
-#ifndef GNOME_ICONDIR
-#define GNOME_ICONDIR "" 
-#endif
 
 GeditMDI *gedit_mdi = NULL;
 BonoboObject *gedit_app_server = NULL;
@@ -77,7 +73,6 @@ struct _CommandLineData
 	gint line_pos;
 };
 
-static void gedit_set_default_icon ();
 static void gedit_load_file_list (CommandLineData *data);
 
 static const struct poptOption options [] =
@@ -97,18 +92,6 @@ static const struct poptOption options [] =
 	{NULL, '\0', 0, NULL, 0}
 };
 
-static void 
-gedit_set_default_icon ()
-{
-	if (!gtk_window_set_default_icon_from_file (GNOME_ICONDIR "/gedit-icon.png", NULL))
-	{
-		g_warning ("Could not set the main window icon.");
-
-		/* In case we haven't yet been installed */
-		gtk_window_set_default_icon_from_file ("../pixmaps/gedit-icon.png", NULL);
-	}
-}
-
 static void 
 gedit_load_file_list (CommandLineData *data)
 {	
@@ -120,9 +103,10 @@ gedit_load_file_list (CommandLineData *data)
 
 	res = gedit_file_open_from_stdin (NULL);
 
-	if (data == NULL) 
+	if ((data == NULL) || (data->file_list == NULL)) 
 	{
 		gedit_file_new ();
+		g_free (data);
 		return;
 	}
 
@@ -159,7 +143,11 @@ gedit_get_command_line_data (GnomeProgram *program)
 		{
 			if (*args[i] == '+')
 			{	
-				data->line_pos = atoi (args[i] + 1);		
+				if (*(args[i] + 1) == '\0')
+					/* goto the last line of the document */
+					data->line_pos = G_MAXINT;
+				else
+					data->line_pos = atoi (args[i] + 1);		
 			}
 			else
 			{
@@ -235,11 +223,11 @@ gedit_handle_automation (GnomeProgram *program)
 		}
 
 		CORBA_sequence_set_release (uri_list, CORBA_TRUE);
-		GNOME_Gedit_Window_openURIList (window, uri_list, &env);
-
-		document = GNOME_Gedit_Application_getActiveDocument (server, &env);
-
-		GNOME_Gedit_Document_setLinePosition (document, data->line_pos, &env);
+		GNOME_Gedit_Window_openURIList (window,
+						uri_list,
+						data->encoding ? encoding_charset : "",
+						data->line_pos,
+						&env);
 
 		g_slist_foreach (data->file_list, (GFunc)g_free, NULL);
 		g_slist_free (data->file_list);
@@ -307,6 +295,7 @@ int
 main (int argc, char **argv)
 {
     	GnomeProgram *program;
+	gchar *display_name;
 	gboolean restored = FALSE;
 	CORBA_Object factory;
 
@@ -329,10 +318,10 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	/* Need to set this to the canonical DISPLAY value, since
-	   that's where we're registering per-display components */
-	bonobo_activation_set_activation_env_value
-		("DISPLAY",
-		 gdk_screen_make_display_name (gdk_screen_get_default ()));
+	 * that's where we're registering per-display components */
+	display_name = gdk_screen_make_display_name (gdk_screen_get_default ());
+	bonobo_activation_set_activation_env_value ("DISPLAY", display_name);
+	g_free (display_name);
 
 	/* check whether we are running already */
         factory = bonobo_activation_activate_from_id
@@ -355,8 +344,8 @@ main (int argc, char **argv)
 	gedit_debug_init ();
 
 	/* Set default icon */
-	gedit_set_default_icon ();
-	
+	gtk_window_set_default_icon_name ("text-editor");
+
 	/* Load user preferences */
 	gedit_prefs_manager_app_init ();
 
