@@ -74,9 +74,12 @@ enum {
 	LAST_SIGNAL
 };
 
-#define KNOWN_LANGUAGES 32
-static GeditLanguage known_languages [KNOWN_LANGUAGES + 1] = 
+static GeditLanguage known_languages [] = 
 {
+	{"af", N_("Afrikaans")},
+	{"am", N_("Amharic")},
+	{"az", N_("Azerbaijani")},
+	{"be", N_("Belarusian")},
 	{"bg", N_("Bulgarian")},
 	{"bn", N_("Bengali")},
 	{"br", N_("Breton")},
@@ -84,32 +87,73 @@ static GeditLanguage known_languages [KNOWN_LANGUAGES + 1] =
 	{"cs", N_("Czech")},
 	{"cy", N_("Welsh")},
 	{"da", N_("Danish")},
-	{"de_de", N_("German (Germany)")},
-	{"de_ch", N_("German (Swiss)")},
+	{"de_AT", N_("German (Austria)")},
+	{"de_DE", N_("German (Germany)")},
+	{"de_CH", N_("German (Swiss)")},
 	{"el", N_("Greek")},
-	{"en_us", N_("English (American)")},
-	{"en_gb", N_("English (British)")},
-	{"en_ca", N_("English (Canadian)")},
+	{"en_US", N_("English (American)")},
+	{"en_GB", N_("English (British)")},
+	{"en_CA", N_("English (Canadian)")},
 	{"eo", N_("Esperanto")},
 	{"es", N_("Spanish")},
+	{"et", N_("Estonian")},
+	{"fa", N_("Persian")},	
 	{"fi", N_("Finnish")},
 	{"fo", N_("Faroese")},
-	{"fr_fr", N_("French (France)")},
-	{"fr_ch", N_("French (Swiss)")},
-	{"ga", N_("Irish (Gaeilge)")},
+	{"fr_FR", N_("French (France)")},
+	{"fr_CH", N_("French (Swiss)")},
+	{"ga", N_("Irish")},
+	{"gd", N_("Scottish Gaelic")},
+	{"gl", N_("Gallegan")},
+	{"gv", N_("Manx Gaelic")},
+	{"he", N_("Hebrew")},
+	{"hi", N_("Hindi")},
+	{"hr", N_("Croatian")},
+	{"hsb", N_("Upper Sorbian")},
+	{"hu", N_("Hungarian")},
+	{"ia", N_("Interlingua (IALA)")},
+	{"id", N_("Indonesian")},
 	{"is", N_("Icelandic")},
 	{"it", N_("Italian")},
+	{"ku", N_("Kurdish")},
+	{"la", N_("Latin")},
+	{"lt", N_("Lithuanian")},
+	{"lv", N_("Latvian")},
+	{"mg", N_("Malagasy")},
+	{"mi", N_("Maori")},
+	{"mk", N_("Macedonian")},
+	{"mn", N_("Mongolian")},
+	{"ms", N_("Malay")},
+	{"mt", N_("Maltese")},
+	{"nb", N_("Norwegian Bokmal")},
 	{"nl", N_("Dutch")},
+	{"nn", N_("Norwegian Nynorsk")},
 	{"no", N_("Norwegian")},
+	{"ny", N_("Nyanja")},
 	{"pl", N_("Polish")},
-	{"pt_pt", N_("Portuguese (Portugal)")},
-	{"pt_br", N_("Portuguese (Brazilian)")},
+	{"pt_PT", N_("Portuguese (Portugal)")},
+	{"pt_BR", N_("Portuguese (Brazilian)")},
+	{"qu", N_("Quechua")},
+	{"ro", N_("Romanian")},
 	{"ru", N_("Russian")},
+	{"rw", N_("Kinyarwanda")},
+	{"sc", N_("Sardinian")},
 	{"sk", N_("Slovak")},
 	{"sl", N_("Slovenian")},
 	{"sv", N_("Swedish")},
+	{"sw", N_("Swahili")},
+	{"ta", N_("Tamil")},
+	{"tet", N_("Tetum")},
+	{"tl", N_("Tagalog")},
+	{"tn", N_("Tswana")},
+	{"tr", N_("Turkish")},
 	{"uk", N_("Ukrainian")},
-	{NULL, NULL}
+	{"uz", N_("Uzbek")},
+	{"vi", N_("Vietnamese")},
+	{"wa", N_("Walloon")},
+	{"yi", N_("Yiddish")},
+	{"zu", N_("Zulu")},
+ 	{NULL, NULL}
 };
 
 static void	gedit_spell_checker_class_init 		(GeditSpellCheckerClass * klass);
